#
# spec file for package quvi
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           quvi
Version:        0.9.5
Release:        5.8
Summary:        Command line tool for parsing flash media stream URLs
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            http://quvi.sourceforge.net/
Source:         http://sourceforge.net/projects/quvi/files/0.9/quvi/quvi-0.9.5.tar.xz
# PATCH-FIX-OPENSUSE
Patch0:         reproducible.patch
Patch1:         quvi-glibc-2.34.patch
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(gobject-2.0) >= 2.24
BuildRequires:  pkgconfig(json-glib-1.0) >= 0.12
BuildRequires:  pkgconfig(libcurl) >= 7.18.2
BuildRequires:  pkgconfig(libquvi-0.9) >= 0.9
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7.8
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
quvi is a command line tool for parsing flash media stream URLs.
It supports many websites including YouTube and Dailymotion.

%prep
%autosetup -p1

%build
%configure \
    --disable-static
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_bindir}/quvi
%{_mandir}/man1/quvi.1%{?ext_man}
%{_mandir}/man1/quvi-dump.1%{?ext_man}
%{_mandir}/man1/quvi-get.1%{?ext_man}
%{_mandir}/man1/quvi-info.1%{?ext_man}
%{_mandir}/man1/quvi-scan.1%{?ext_man}
%{_mandir}/man5/quvirc.5%{?ext_man}

%changelog
* Tue Oct 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add quvi-glibc-2.34.patch: Fix build with glibc 2.34, where
  'write' is an internally used name.
* Sun Jan 22 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Mon Feb 10 2014 dimstar@opensuse.org
- Update to version 0.9.5:
  + Fix compilation errors:
  - array initialized from parenthesized string constant.
  - comma at end of enumerator list.
  + linput: Rewrite input parsing completely.
  + quvi-dump: Do not escape reserved chars in URLs.
- Changes from version 0.9.4:
  + Add --enable-cookies.
  + g_type_init: no longer needs to be called.
  + Revise --version output.
  + --version: Add "configuration" to output.
  + --version: Add QUVI_VERSION_SCRIPTS_CONFIGURATION to output.
- Changes from version 0.9.3.1:
  + AC_PREREQ: Bump to 2.69/
  + DOC: Add chevs and (missing) ARGNAMEs to "config:" lines.
  + status: Mark message output for translation.
  + status: Redo frames to look similar to progressbar frames.
* Mon Aug 26 2013 dimstar@opensuse.org
- Update to version 0.9.3:
  + cb_status: Update for user_data
  + configure.ac: Require a2x when building from git.
  + DOC: --exec: Add details to %%e and %%f sequences.
  + DOC: --exec: Add the missing %%e sequence.
  + DOC: quvi-get(1): Revise the output-regex description.
  + FIX: configure.ac: AS_IF for date(1).
  + FIX: regex pattern extraction (e.g. --output-regex).
  + status: Replace use of GDateTime with static frames.
  + --version: Add CC and CFLAGS to output.
  + --version: libquvi: Add QUVI_VERSION_BUILD_CC_FLAGS to output.
- Add new BuildRequires, based on configure checks:
  + pkgconfig(glib-2.0)
  + pkgconfig(gobject-2.0)
  + pkgconfig(json-glib-1.0)
  + pkgconfig(libxml-2.0)
- Replace pkgconfig(libquvi) BuildRequires with
  pkgconfig(libquvi-0.9), following the port to libquvi-0.9.
* Sat May  4 2013 grauwolf@geekosphere.org
- Update to version 0.4.2
  + Add "%%e" to print the extension of the linked file
  + Add "%%h" to print the thumbnail URL for a link
* Tue Jan 10 2012 vuntz@opensuse.org
- Update to version 0.4.1:
  + Accept multiple occurences of --exec
  + Add verbosity level 'mute'
  + Add new options: --export-format, --export-level, --verbosity,
  - -category, --feature
  + Deprecate options: --verbose-libcurl, --category-*, --quiet,
  - -no-*, --xml
  + Properly escape strings passed to shell
- Changes from version 0.4.0:
  + Split old code in three modules: quvi, libquvi,
    libquvi-scripts.
  + Make --category-all new default (prev. --category-http)
  + Extend --exec to support %%t, page title
  + Remove deprecated "--format (help|list)"
  + Remove deprecated "--no-shortened"
  + Remove deprecated "--old"
- Completely rework packaging, following the upstream split in
  three modules. This can be considered as a new package.
* Tue Nov 29 2011 ro@suse.de
- add missing include stdio.h to fix build
* Tue Aug  9 2011 dnh@opensuse.org
- fixed soname in .spec (warnings: TODO)
* Sun Aug  7 2011 dnh@opensuse.org
- upstream update to 0.2.19 (YT has changed API once again)
* Tue May 31 2011 nmarques@opensuse.org
- Update to version 0.2.16:
  + Converted spec to use pkgconfig() calls;
  + Rename '-s,--no-shortened' -> '-r,--no-resolve';
  + Add support for reading input from files;
  + Add "Network interface" (quvi_net_*, QUVI_NET_*, quvi/net.h);
  + Add examples/callback_libsoup.c;
  + Make LUA errors more informative (e.g. fname, func, etc.);
  + Add "Linked list interface" (quvi_llst_*, quvi/llst.h);
  + Add quvi_supported_ident (#44);
  + Add quvi_supported_ident_close;
  + Add quvi_ident_getprop;
  + Deprecate remaining symbols that use 'video' and 'link' in
    names;
  + Rename (&depr.) QUVISTATUS_SHORTENED -> QUVISTATUS_RESOLVE;
  + Rename (&depr.) QUVIOPT_NOSHORTENED -> QUVIOPT_NORESOLVE;
  + Deprecate QUVIINFO_HTTPCODE, QUVIPROP_HTTPCODE;
  + Changes: Webscripts
  - Pass _quvi_media_t to quvi object functions in LUA reg.
    index;
  - collegehumor.lua: Add 'best' ('hq') format;
  - LUA: Add resolve function to quvi object;
  - Add bikeradar.lua (#50);
  - Add guardian.lua (#51);
  - Add more NSFW scripts;
  - Add blip.lua (#39);
  + Changes: Build system:
  - Add --with-soup (see INSTALL);
  + Changes: Documentation:
  - INSTALL: Remove list of (obsolete) env. variables;
  - Add doc/WebsiteScriptGuideLines;
  - API: Reorganize "Modules";
  + Bugfixes: Webscripts:
  - collegehumor.lua:51: server response code 404 (#35);
  - vimeo.lua:62: no match: hd button (#48);
  - liveleak.lua:48: no match: config (#47);
* Mon Apr 11 2011 nmarques@opensuse.org
- Update to version 0.2.14:
  + Adds new tests;
  + Many fixes on .lua files;
  + Support for newer sites;
  + Adds ART TV support;
  + Extends HTML entity conversion table;
  + Many other small fixes (ChangeLog file)...
- Spec changes: updated license (LGPLv2.1), fixed %%files, added
  %%{soname} macro for easier maintenance, other minor fixes.
* Wed Apr 28 2010 mvyskocil@suse.cz
- Initial SUSE packaging of quvi 0.1.4
